SENTRY_REDMINE_API_KEY = 'dcf65acc1c96ecc55dec8ed20cc69f10108b2ec7'
SENTRY_REDMINE_URL = 'http://localhost:3000'
SENTRY_REDMINE_PROJECT_SLUG = 'sentry'